'use strict';

let MongoClient = require('mongodb').MongoClient;
let ReplSet = require('mongodb').ReplSet;
let Server = require('mongodb').Server;
let Db = require('mongodb').Db;
let thunkify = require('thunkify');
let connections = {};

class MongodbConnection {
  static * get(config) {
    config.mongoHosts = config.mongoHosts || 'localhost';
    if (!Array.isArray(config.mongoHosts)) {
      config.mongoHosts = [config.mongoHosts];
    }
    let key = `${config.mongoHosts.join(',')}/${config.db}`;
    let auth = config.auth;
    let replicaSet = config.replicaSet;
    let connection = connections[key];
    let uriDecodeAuth = false;
    if (!connection) {
      let constr;
      if (auth) {
        constr = `mongodb://${auth.username}:${auth.password}@${config.mongoHosts.join(',')}/${config.db}?authSource=admin&readPreference=nearest`;
        uriDecodeAuth = true;
      } else {
        constr = `mongodb://${config.mongoHosts.join(',')}/${config.db}?readPreference=nearest`;
      }
      if (replicaSet) {
        constr += constr.indexOf('?') === -1 ? `?replicaSet=${replicaSet}` : `&replicaSet=${replicaSet}`;
      }
      try {
        connection = yield MongoClient.connect(constr, {
          uri_decode_auth: uriDecodeAuth
        });
      } catch (e) {
        return null;
      }
      connection.on('close', function() {
        delete connections[key];
      });
      connection.on('error', function() {
        delete connections[key];
      });
      connection.on('timeout', function() {
        delete connections[key];
      });
      connections[key] = connection;
    }
    return connection;
  }
}

module.exports = MongodbConnection;
