'use strict'

var assert = require("assert");
var MongodbConnection = require('./index');
var co = require('co');
var thunkify = require('thunkify');

describe('MongodbConnection', function() {
  let connection, otherConnection;
  it('连接并操作数据', function(done) {
    co(function*() {
      connection = yield MongodbConnection.get({
        db: 'test'
      });
      let collection = connection.collection('user');
      yield thunkify(collection.remove.bind(collection))({});
      yield thunkify(collection.insert.bind(collection))({
        name: 'seon'
      });
      let result = yield thunkify(collection.findOne.bind(collection))();
      assert.equal(result.name, 'seon');
      done();
    }).then(function() {}, function(err) {
      console.log(err)
    });
  });

  it('多次连接并操作数据', function(done) {
    co(function*() {
      let connection2 = yield MongodbConnection.get({
        db: 'test'
      });
      assert.equal(connection2, connection);
      let collection = connection2.collection('user');
      yield thunkify(collection.remove.bind(collection))({});
      yield thunkify(collection.insert.bind(collection))({
        name: 'seon'
      });
      let result = yield thunkify(collection.findOne.bind(collection))();
      assert.equal(result.name, 'seon');
      done();
    }).then(function() {}, function(err) {
      console.log(err)
    });
  });

  it('连接多个DB', function(done) {
    co(function*() {
      let connection2 = yield MongodbConnection.get({
        db: 'other'
      });
      assert.notEqual(connection2, connection);
      let collection = connection.collection('user');
      let collection2 = connection2.collection('user');
      yield thunkify(collection.remove.bind(collection))({});
      yield thunkify(collection2.remove.bind(collection))({});
      yield thunkify(collection.insert.bind(collection))({
        name: 'seon'
      });
      let result = yield thunkify(collection2.findOne.bind(collection2))();
      assert.equal(result, null);
      result = yield thunkify(collection.findOne.bind(collection))();
      assert.equal(result.name, 'seon');
      done();
    }).then(function() {}, function(err) {
      console.log(err)
    });
  });

  it('连接带认证的DB', function(done) {
    co(function*() {
      let connection2 = yield MongodbConnection.get({
        db: 'test',
        mongoHosts: '192.168.20.7',
        auth: {
          username: 'doudou',
          password: 'DouDou0122'
        }
      });
      let collection2 = connection2.collection('authtest');
      yield thunkify(collection2.insert.bind(collection2))({
        name: 'seon'
      });
      let result = yield thunkify(collection2.findOne.bind(collection2))();
      assert.equal(result.name, 'seon');
      yield thunkify(collection2.remove.bind(collection2))({});
      done();
    }).then(function() {}, function(err) {
      console.log(err)
    });
  });

});
